CacheHitHandler class

Handler for CacheInterceptor.onHit.

.create() is for internal use by the package only.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(CacheHitData data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reject() → void
Force a re-download by treating this hit as a miss.
resolve(FileInfo fileInfo) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited