logLevel property
The global log level for all cache manager instances.
Implementation
static CacheManagerLogLevel logLevel = CacheManagerLogLevel.none;
The global log level for all cache manager instances.
static CacheManagerLogLevel logLevel = CacheManagerLogLevel.none;