CacheMissHandler class

Handler for CacheInterceptor.onMiss.

.create() is for internal use by the package only.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

next(CacheMissData data) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(FileInfo fileInfo) → void
Provide a synthetic FileInfo to bypass the download.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited