CacheStoreData class

Data passed to CacheInterceptor.onStore.

Note: file is a dart:io File. This class is only available on native IO platforms (Android, iOS, macOS, Linux, Windows). It is not available on web.

Constructors

CacheStoreData({required String url, required String key, required CacheEntryMetadata metadata, required File file})
const

Properties

file File
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
metadata CacheEntryMetadata
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited