disablePlaceholderOnCacheHit property
When true (the default), the placeholder and fade-in/out animations are skipped when the image is already available in the disk cache. This prevents an unnecessary visual flicker for images that load almost instantly from cache.
Set to false to always show the placeholder and fade animations,
regardless of cache status.
Implementation
final bool disablePlaceholderOnCacheHit;