CachedNetworkImageProvider class

IO implementation of the CachedNetworkImageProvider; the ImageProvider to load network images using a cache.

Inheritance
Annotations

Constructors

CachedNetworkImageProvider(String url, {int? maxHeight, int? maxWidth, double scale = 1.0, Duration minimumGifFrameDuration = const Duration(milliseconds: 100), bool animate = true, ErrorListener? errorListener, Map<String, String>? headers, BaseCacheManager? cacheManager, String? cacheKey, ImageRenderMethodForWeb imageRenderMethodForWeb = ImageRenderMethodForWeb.HtmlImage})
Creates an ImageProvider which loads an image from the url, using the scale. When the image fails to load errorListener is called.
const

Properties

animate → bool
Whether multi-frame images, such as GIFs, play automatically.
final
cacheKey → String?
Cache key of the image to cache
final
cacheManager → BaseCacheManager?
CacheManager from which the image files are loaded.
final
errorListener → ErrorListener?
Listener to be called when images fails to load.
final
hashCode → int
The hash code for this object.
no setteroverride
headers → Map<String, String>?
Set headers for the image provider, for example for authentication.
final
imageRenderMethodForWeb → ImageRenderMethodForWeb
Render option for images on the web platform.
final
maxHeight → int?
Maximum height of the loaded image. If not null and using an ImageCacheManager the image is resized on disk to fit the height.
final
maxWidth → int?
Maximum width of the loaded image. If not null and using an ImageCacheManager the image is resized on disk to fit the width.
final
minimumGifFrameDuration → Duration
The minimum frame duration applied to GIF images when decoded frame durations are extremely short.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
Scale of the image
final
url → String
Web url of the image to load
final

Methods

createStream(ImageConfiguration configuration) → ImageStream
Called by resolve to create the ImageStream it returns.
inherited
evict({ImageCache? cache, ImageConfiguration configuration = ImageConfiguration.empty}) → Future<bool>
Evicts an entry from the image cache.
inherited
loadBuffer(CachedNetworkImageProvider key, DecoderBufferCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
loadImage(CachedNetworkImageProvider key, ImageDecoderCallback decode) → ImageStreamCompleter
Converts a key into an ImageStreamCompleter, and begins fetching the image.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
obtainCacheStatus({required ImageConfiguration configuration, ImageErrorListener? handleError}) → Future<ImageCacheStatus?>
Returns the cache location for the key that this ImageProvider creates.
inherited
obtainKey(ImageConfiguration configuration) → Future<CachedNetworkImageProvider>
Converts an ImageProvider's settings plus an ImageConfiguration to a key that describes the precise image to load.
override
resolve(ImageConfiguration configuration) → ImageStream
Resolves this image provider using the given configuration, returning an ImageStream.
inherited
resolveStreamForKey(ImageConfiguration configuration, ImageStream stream, CachedNetworkImageProvider key, ImageErrorListener handleError) → void
Called by resolve with the key returned by obtainKey.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Properties

defaultCacheManager ↔ BaseCacheManager
The default cache manager used for image caching.
getter/setter pair