headers property
Set headers for the image provider, for example for authentication.
Note on Flutter Web: Headers are only supported when using
ImageRenderMethodForWeb.HttpGet render method. The default
ImageRenderMethodForWeb.HtmlImage does not support custom headers.
If you provide headers on Web, you must also set
imageRenderMethodForWeb: ImageRenderMethodForWeb.HttpGet.
Implementation
final Map<String, String>? headers;