CleanupStrategy class abstract

Defines the order in which cache entries are evicted when the cache exceeds DefaultCacheManager.maxNrOfCacheObjects.

Implement this class to provide a custom eviction policy. The first entries in the returned list will be evicted first.

Implementers

Constructors

CleanupStrategy()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortForEviction(List<MapEntry<String, CacheEntryMetadata>> entries) List<MapEntry<String, CacheEntryMetadata>>
Sorts entries so that the entries to evict first appear at the beginning of the returned list.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited