connectionTimeout property
Maximum duration to wait for the server to respond with headers.
When null, no connection timeout is applied.
Implementation
final Duration? connectionTimeout;
Maximum duration to wait for the server to respond with headers.
When null, no connection timeout is applied.
final Duration? connectionTimeout;