HttpResponseData class

Immutable response data passed through the HTTP interceptor chain.

Constructors

HttpResponseData({required StreamedResponse response, required String originalUrl})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
originalUrl String
The URL of the original request that produced this response.
final
response → StreamedResponse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited