ImageFormatDetector class

Utility to detect image formats that are not supported by Flutter's standard image codec (e.g. SVG).

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

detectUnsupportedFormat(Uint8List bytes) String?
Returns the detected format name for bytes, or null if the format is supported by Flutter's standard codec.
isSvg(Uint8List bytes) bool
Returns true if bytes appear to be an SVG image.