TtlCleanupStrategy class final

Evicts entries with the earliest expiry date first (TTL-based).

This matches the original DefaultCacheManager behaviour and is the default strategy when no CleanupStrategy is provided.

Inheritance

Constructors

TtlCleanupStrategy()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sortForEviction(List<MapEntry<String, CacheEntryMetadata>> entries) List<MapEntry<String, CacheEntryMetadata>>
Sorts entries so that the entries to evict first appear at the beginning of the returned list.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited