UnsupportedImageFormatException class
Exception thrown when the image bytes cannot be decoded by Flutter's standard image codec (e.g. SVG images).
When caught, the bytes field contains the raw cached file bytes so that
a custom renderer (such as flutter_svg) can display the image.
- Implemented types
Constructors
- UnsupportedImageFormatException({required Uint8List bytes, required String url, String? detectedFormat})
-
Creates an UnsupportedImageFormatException.
const
Properties
- bytes → Uint8List
-
The raw bytes of the cached file.
final
- detectedFormat → String?
-
The detected image format, e.g.
"svg", if known.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The original URL of the image.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited