getFileStream abstract method
Get the file from the cache and/or online, depending on availability and age.
Downloaded from url, headers can be used for example for
authentication. The files are returned as a stream. First the cached
file if available, when the cached file is too old the newly downloaded
file is returned afterwards.
The FileResponse is either a FileInfo object for fully downloaded
files or a DownloadProgress object for when a file is being downloaded.
The DownloadProgress objects are only dispatched when withProgress is
set on true and the file is not available in the cache.
Implementation
Stream<FileResponse> getFileStream(
String url, {
String? key,
Map<String, String>? headers,
bool withProgress,
});