CacheInterceptor class abstract
Abstract interceptor for cache lookup and storage events.
This interceptor is specific to the IO DefaultCacheManager and is not available on web targets.
Override any hook you need; all default to passing through unchanged.
Each hook MUST call exactly one of handler.next, handler.resolve, or
handler.reject. Failing to call any method will permanently stall the
request pipeline.
Constructors
- CacheInterceptor()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onHit(
CacheHitData data, CacheHitHandler handler) → void -
onMiss(
CacheMissData data, CacheMissHandler handler) → void -
onStore(
CacheStoreData data, CacheStoreHandler handler) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited