httpHeaders property
Optional headers for the http request of the image url.
Note on Flutter Web: Headers are only supported when using
ImageRenderMethodForWeb.HttpGet render method. The default
ImageRenderMethodForWeb.HtmlImage does not support custom headers.
If you provide headers on Web, you must also set
imageRenderMethodForWeb: ImageRenderMethodForWeb.HttpGet.
Implementation
final Map<String, String>? httpHeaders;