FileInfo class

FileInfo contains the fetched File next to some info on the validity and the origin of the file.

Inheritance

Constructors

FileInfo(File file, FileSource source, DateTime validTill, String originalUrl, {int statusCode = 200})
const

Properties

file → File
The fetched file.
final
hashCode int
The hash code for this object.
no setterinherited
originalUrl String
Url from which the file was fetched.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source FileSource
Source of the file, can be cache or online (web).
final
statusCode int
HTTP status code of the response.
final
validTill DateTime
Validity date of the file. After this date the validity is not guaranteed and the CacheManager will try to update the file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited