FileResponse class abstract
Base class for responses from the cache manager.
A FileResponse is either a FileInfo object for fully downloaded files or a DownloadProgress object for when a file is being downloaded.
Constructors
- FileResponse(String originalUrl)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- originalUrl → String
-
Url from which the file was fetched.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited