HttpExceptionWithStatus class

An HTTP exception that includes the HTTP status code.

This replaces flutter_cache_manager's HttpExceptionWithStatus and avoids depending on dart:io's HttpException which is not available on web.

Implemented types

Constructors

HttpExceptionWithStatus(int statusCode, String message, {Uri? uri})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Error message describing the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
The HTTP status code.
final
uri → Uri?
The URI that caused the exception, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited