originalUrl property
The URL of the original request that produced this response.
This field is informational. Changing it does not affect how the response is stored in the cache — the original request URL is always used as the cache key and metadata URL.
Implementation
final String originalUrl;