ImageCacheManager mixin

Extended cache manager with image-specific methods.

Implementations of this mixin provide getImageFile which supports fetching and optionally resizing images before caching.

Superclass constraints
Mixin applications

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → Future<void>
Close the cache database.
inherited
emptyCache() → Future<void>
Remove all files from the cache.
inherited
getFileFromCache(String key, {bool ignoreMemCache = false}) → Future<FileInfo?>
Get the file from the cache.
inherited
getFileStream(String url, {String? key, Map<String, String>? headers, bool withProgress}) → Stream<FileResponse>
Get the file from the cache and/or online, depending on availability and age.
inherited
getImageFile(String url, {String? key, Map<String, String>? headers, bool withProgress = false, int? maxHeight, int? maxWidth}) → Stream<FileResponse>
Returns a resized image file to fit within maxHeight and maxWidth.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
putFile(String url, List<int> fileBytes, {String? key, String? eTag, Duration maxAge = const Duration(days: 30), String fileExtension = 'file'}) → Future<File>
Put a file in the cache.
inherited
removeFile(String key) → Future<void>
Remove a file from the cache.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited